# Slurmer

This package is designed to run heavy loads in a computer cluster. 

For now we only support the SLURM task scheduler but PRs are welcome.

You can find the documentation [here](https://jmigual.github.io/slurmer/)
